/*
 * $Id: spm-migpost71.sql 101389 2011-11-25 01:51:25Z rlowery $
 *
 * Finish migrating a ManageSoft 6.1 database into ManageSoft 6.5 format.
 *
 * Use migprep.sql first, then schema.sql, then this, and finally
 * install Managesoft 7.0 which will create the stored procedures.
 *
 * Called after building the new tables, this script:
 * - migrates data from old tables
 *
 * Copyright 2011 Flexera Software LLC
 */

USE ManageSoft
GO

/*
 * Check that we are upgrading from a 6.6 database...
 */
DECLARE @spm_schema_version char(10)
SET @spm_schema_version = (SELECT Value FROM DatabaseConfiguration
                WHERE Property = 'SPMSchemaVersion')

IF @spm_schema_version IS NULL
	SET @spm_schema_version = (SELECT Value FROM DatabaseConfiguration
			WHERE Property = 'SchemaVersion')

IF (@spm_schema_version = '7.0')
BEGIN
        PRINT 'Completing migration to ManageSoft SPM 7.1 database schema...'
END
ELSE IF (@spm_schema_version = '7.1')
BEGIN
        RAISERROR ('Your ManageSoft SPM database has already been migrated to the 7.1 schema.', 16, 1)
        RAISERROR ('For more information on migrating your database, refer to the ManageSoft Upgrade Guide.', 16, 1)
END
ELSE
BEGIN
	RAISERROR ('This script can only migrate from the ManageSoft SPM database schema version 7.0.', 16, 1)
	RAISERROR ('Please migrate your database schema to version 7.0 before executing this script again.', 16, 1)
        RAISERROR ('For more information on migrating your database, refer to the ManageSoft Upgrade Guide.', 16, 1)
END
GO


--===========================================================================
--		Populate the SecurityPatchUIProductGroup table
--===========================================================================

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchUIProductGroup'
)
BEGIN
	PRINT 'Populate the SecurityPatchUIProductGroup table'

	INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('Microsoft Office 2000', 'Microsoft Office 2000')

	INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('Microsoft Office XP', 'Microsoft Office XP')

	INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('Microsoft Office 2003', 'Microsoft Office 2003')
		
		
	INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
	    VALUES('Windows Media Player', 'Windows Media Player 6.4')

	INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('Windows Media Player', 'Windows Media Player 6.4 for Windows NT 4.0')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('Windows Media Player', 'Windows Media Player 6.4 for Windows 2000')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('Windows Media Player', 'Windows Media Player 6.4 for Windows XP')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('Windows Media Player', 'Windows Media Player 6.4 for Windows Server 2003')    

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('Windows Media Player', 'Windows Media Player 7.0')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('Windows Media Player', 'Windows Media Player 7.1')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
			VALUES('Windows Media Player', 'Windows Media Player 9.0')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
			VALUES('Windows Media Player', 'Windows Media Player 9 Series')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
			VALUES('Windows Media Player', 'Windows Media Player 9 Series for Windows XP')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
			VALUES('Windows Media Player', 'Windows Media Player for Windows XP')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
			VALUES('Windows Media Player', 'Windows Media Player 9 Series for Windows Server 2003')
	
	INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('Exchange Server', 'Exchange 2000 Enterprise Server')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('Exchange Server', 'Exchange 2000 Server')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('Exchange Server', 'Exchange Server')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('Exchange Server', 'Exchange Server 2003')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('Exchange Server', 'Exchange Server 5.0')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('Exchange Server', 'Exchange Server 5.5')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('MDAC', 'MDAC 2.1')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('MDAC', 'MDAC 2.5')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('MDAC', 'MDAC 2.6')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('MDAC', 'MDAC 2.7')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('MDAC', 'MDAC 2.8')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('Virtual Machine', 'Microsoft Virtual Machine (VM)')
	
	INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('MSXML', 'MSXML 2.6')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('MSXML', 'MSXML 3.0')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('MSXML', 'MSXML 4.0')

    INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('MSXML', 'MSXML 6.0')

END
GO


IF EXISTS(
        SELECT  *
        FROM    DatabaseConfiguration
        WHERE   Property = 'SPMSchemaVersion'
)
        BEGIN
                UPDATE DatabaseConfiguration SET Value = '7.1'
                        WHERE Property = 'SPMSchemaVersion'
        END
ELSE
        BEGIN
	INSERT DatabaseConfiguration (Property, Value)
		VALUES ('SPMSchemaVersion','7.1')
	END
GO

