/*
 * $Id: spm-migpost715.sql 101389 2011-11-25 01:51:25Z rlowery $
 *
 * Finish migrating a ManageSoft 6.1 database into ManageSoft 6.5 format.
 *
 * Use migprep.sql first, then schema.sql, then this, and finally
 * install Managesoft 7.0 which will create the stored procedures.
 *
 * Called after building the new tables, this script:
 * - migrates data from old tables
 *
 * Copyright 2011 Flexera Software LLC
 */

USE ManageSoft
GO

/*
 * Check that we are upgrading from a 6.6 database...
 */
DECLARE @spm_schema_version char(10)
SET @spm_schema_version = (SELECT Value FROM DatabaseConfiguration
                WHERE Property = 'SPMSchemaVersion')

IF @spm_schema_version IS NULL
	SET @spm_schema_version = (SELECT Value FROM DatabaseConfiguration
			WHERE Property = 'SchemaVersion')

IF (@spm_schema_version = '7.1')
BEGIN
	PRINT 'Completing migration to ManageSoft SPM 7.1.5 database schema...'
END
ELSE IF (@spm_schema_version = '7.1.5')
BEGIN
        RAISERROR ('Your ManageSoft SPM database has already been migrated to the 7.1.5 schema.', 16, 1)
        RAISERROR ('For more information on migrating your database, refer to the ManageSoft Upgrade Guide.', 16, 1)
END
ELSE
BEGIN
	RAISERROR ('This script can only migrate from the ManageSoft SPM database schema version 7.1.', 16, 1)
	RAISERROR ('Please migrate your database schema to version 7.1 before executing this script again.', 16, 1)
        RAISERROR ('For more information on migrating your database, refer to the ManageSoft Upgrade Guide.', 16, 1)
END
GO


--===========================================================================
--		Populate the SecurityPatchUIProductGroup table
--===========================================================================

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchUIProductGroup'
)
BEGIN
	PRINT 'Populate the SecurityPatchUIProductGroup table'

	INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('RedHat Linux', 'RedHat Enterprise Linux AS 2.1')
	INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('RedHat Linux', 'RedHat Enterprise Linux AS 3')
	INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('RedHat Linux', 'RedHat Enterprise Linux ES 2.1')
	INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('RedHat Linux', 'RedHat Enterprise Linux ES 3')
	INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('RedHat Linux', 'RedHat Enterprise Linux WS 2.1')
	INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
		VALUES('RedHat Linux', 'RedHat Enterprise Linux WS 3')
END

GO

--===========================================================================
--		Populate the SecurityPatchResource table
--===========================================================================

PRINT 'Populate the SecurityPatchResource table'
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatch'
)
BEGIN
	-- Populate resources
	INSERT SecurityPatchResource
	(SecurityPatchID, ResourceURL, ArchitectureID, LanguageID, Checksum, ActualResourceURL, LocalPath)
	(
		SELECT	PatchID, DownloadLocation, 1, 1, NULL, ActualDownloadLocation, StagedFile
		FROM	SecurityPatch
		WHERE	PatchID <> 0
		AND		NOT EXISTS(SELECT * FROM SecurityPatchResource WHERE SecurityPatchID = PatchID)
	)
END

GO

--===========================================================================
--		Alter the SecurityPatch table
--===========================================================================

PRINT 'Fix SecurityPatch staged files paths'
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatch'
)
BEGIN
	-- Strip filename off staged file
	UPDATE	SecurityPatch
	SET		StagedFile = SUBSTRING(StagedFile, 1, LEN(StagedFile) - CHARINDEX('\', REVERSE(StagedFile)))
	WHERE	PatchID <> 0
END

GO

--===========================================================================
--		Update SPM schema version
--===========================================================================

IF EXISTS(
	SELECT  *
	FROM    DatabaseConfiguration
	WHERE   Property = 'SPMSchemaVersion'
)
	BEGIN
		UPDATE DatabaseConfiguration SET Value = '7.1.5'
		WHERE Property = 'SPMSchemaVersion'
	END
ELSE
	BEGIN
		INSERT DatabaseConfiguration (Property, Value)
		VALUES ('SPMSchemaVersion','7.1.5')
	END
GO

