/*
 * $Id: spm-migpost72.sql 101389 2011-11-25 01:51:25Z rlowery $
 *
 * Finish migrating a ManageSoft 6.1 database into ManageSoft 6.5 format.
 *
 * Use migprep.sql first, then schema.sql, then this, and finally
 * install Managesoft 7.2 which will create the stored procedures.
 *
 * Called after building the new tables, this script:
 * - migrates data from old tables
 *
 * Copyright 2011 Flexera Software LLC
 */

USE ManageSoft
GO

/*
 * Check that we are upgrading from a 7.1.5 database...
 */
DECLARE @schema_version char(10)
SET @schema_version = (SELECT Value FROM DatabaseConfiguration
                WHERE Property = 'SchemaVersion')
		
DECLARE @spm_schema_version char(10)
SET @spm_schema_version = (SELECT Value FROM DatabaseConfiguration
                WHERE Property = 'SPMSchemaVersion')

IF @spm_schema_version IS NULL
	SET @spm_schema_version = @schema_version

IF (@spm_schema_version = '7.1.5')
BEGIN
	PRINT 'Completing migration to ManageSoft SPM 7.2 database information...'
END
ELSE IF (@spm_schema_version = '7.2')
BEGIN
	PRINT 'Your ManageSoft database has already been migrated to 7.2'
	PRINT 'For more information on migrating your database, refer to the ManageSoft Upgrade Guide.'
	RETURN
END
ELSE
BEGIN
	PRINT 'This script can only migrate database information from ManageSoft 7.1.5, not from any previous versions.'
	PRINT 'Please migrate any previous versions of your ManageSoft database first.'
	PRINT 'For more information on migrating your database, refer to the ManageSoft Upgrade Guide.'
	RETURN
END
GO



--===========================================================================
--		Update SPM schema version
--===========================================================================

IF EXISTS(
	SELECT  *
	FROM    DatabaseConfiguration
	WHERE   Property = 'SPMSchemaVersion'
)
	BEGIN
		UPDATE DatabaseConfiguration SET Value = '7.2'
		WHERE Property = 'SPMSchemaVersion'
	END
ELSE
	BEGIN
		INSERT DatabaseConfiguration (Property, Value)
		VALUES ('SPMSchemaVersion','7.2')
	END
GO

