/*
 * $Id: spm-migpost75.sql 101389 2011-11-25 01:51:25Z rlowery $
 *
 * Finish migrating a ManageSoft 7.2 database into ManageSoft 7.5 format.
 *
 * Use migprep.sql first, then schema.sql, then this, and finally
 * install Managesoft 7.5 which will create the stored procedures.
 *
 * Called after building the new tables, this script:
 * - migrates data from old tables
 *
 * Copyright 2011 Flexera Software LLC
 */

USE ManageSoft
GO

--===========================================================================
--		Update SPM schema version
--===========================================================================

IF EXISTS(
	SELECT  *
	FROM    DatabaseConfiguration
	WHERE   Property = 'SPMSchemaVersion'
)
	BEGIN
		UPDATE DatabaseConfiguration SET Value = '7.5'
		WHERE Property = 'SPMSchemaVersion'
	END
ELSE
	BEGIN
		INSERT DatabaseConfiguration (Property, Value)
		VALUES ('SPMSchemaVersion','7.5')
	END
GO

--===========================================================================
--		Populate the SecurityPatchUIProductGroup table
--===========================================================================

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchUIProductGroup'
)
BEGIN
	PRINT 'Populate the SecurityPatchUIProductGroup table'

	INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
	      VALUES('SuSE Linux', 'SuSE Linux 9.0')
	INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
	      VALUES('SuSE Linux', 'SuSE Linux 9.1')
	INSERT INTO SecurityPatchUIProductGroup(GroupName, Product)
	      VALUES('SuSE Linux', 'SuSE Linux 9.2')
END
GO

--===========================================================================
--		Populate the SecurityPatchOperatingSystem table
--===========================================================================

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchOperatingSystem'
)
BEGIN
	PRINT 'Populate the SecurityPatchOperatingSystem table'

	INSERT INTO SecurityPatchOperatingSystem(OperatingSystemID, Description, Selected, Visible)
	      VALUES(79, 'SuSE Linux', 1, 1)
END
GO

