/*
 * $Id: spm-migpost76.sql 101389 2011-11-25 01:51:25Z rlowery $
 *
 * Finish migrating a ManageSoft 7.5 database into ManageSoft 7.6 format.
 *
 * Use migprep.sql first, then schema.sql, then this, and finally
 * install Managesoft 7.6 which will create the stored procedures.
 *
 * Called after building the new tables, this script:
 * - migrates data from old tables
 *
 * Copyright 2011 Flexera Software LLC
 */

USE ManageSoft
GO

--===========================================================================
--		Update SPM schema version
--===========================================================================

IF EXISTS(
	SELECT  *
	FROM    DatabaseConfiguration
	WHERE   Property = 'SPMSchemaVersion'
)
	BEGIN
		UPDATE DatabaseConfiguration SET Value = '7.6'
		WHERE Property = 'SPMSchemaVersion'
	END
ELSE
	BEGIN
		INSERT DatabaseConfiguration (Property, Value)
		VALUES ('SPMSchemaVersion','7.6')
	END
GO

--===========================================================================
--		Populate the SecPatch_Location table
--===========================================================================

IF NOT EXISTS (
	SELECT *
	FROM SecPatch_Location
	WHERE LocationID = 0
) AND NOT EXISTS (
	SELECT * FROM SecPatch_Location
	WHERE Path = 'Other'
)
BEGIN
	PRINT 'Populate the SecPatch_Location table'

	INSERT INTO SecPatch_Location (LocationID, Path, AbsolutePath)
	      VALUES(0, 'Other', '')
END
GO

--===========================================================================
--		Populate the SecurityPatchUIProductGroup table
--===========================================================================

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchUIProductGroup'
)
BEGIN
	PRINT 'Populate the SecurityPatchUIProductGroup table'

	SET IDENTITY_INSERT SecurityPatchUIProductGroup ON
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Visual Studio .NET', 'Visual Studio .NET 2002', 83)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Visual Studio .NET', 'Visual Studio .NET 2003', 84)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('.NET Framework', '.NET Framework 1.0', 85)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('.NET Framework', '.NET Framework 1.0 SP2', 86)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('.NET Framework', '.NET Framework 1.0 SP3', 87)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('.NET Framework', '.NET Framework 1.1', 88)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('.NET Framework', '.NET Framework 1.1 RTM', 89)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('.NET Framework', '.NET Framework 1.1 RTM for Windows Server 2003', 90)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('.NET Framework', '.NET Framework 1.1 SP1', 91)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('.NET Framework', '.NET Framework 1.1 SP1 for Windows Server 2003', 92)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Picture It!/Digital Image', 'Picture It! or Digital Image v6', 93)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Picture It!/Digital Image', 'Picture It! or Digital Image v7', 94)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Picture It!/Digital Image', 'Picture It! or Digital Image v9', 95)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Microsoft Producer', 'Producer for 2003', 96)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Journal Viewer', 'Journal Viewer 1.5', 97)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Visual FoxPro', 'Visual FoxPro 8.0', 98)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('Windows Sharepoint Services', 'Windows Sharepoint Services', 99)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MSN Messenger', 'Windows Messenger 4.7.0.2009', 100)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MSN Messenger', 'Windows Messenger 4.7.0.3000', 101)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MSN Messenger', 'Windows Messenger 5.0', 102)
	INSERT INTO SecurityPatchUIProductGroup (GroupName, Product, SecurityPatchUIProductGroupID)
		VALUES ('MSN Messenger', 'MSN Messenger', 103)
	SET IDENTITY_INSERT SecurityPatchUIProductGroup OFF
END
GO

--===========================================================================
--		Populate the SecurityPatchApplication table
--===========================================================================

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatchApplication'
)
BEGIN
	PRINT 'Populate the SecurityPatchApplication table'

	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (83, 'Visual Studio .NET', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (85, '.NET Framework', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (93, 'Picture It!/Digital Image', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (96, 'Microsoft Producer', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (97, 'Journal Viewer', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (98, 'Visual FoxPro', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (99, 'Windows Sharepoint Services', 1, 1)
	INSERT INTO SecurityPatchApplication (ApplicationID, Description, Selected, Visible)
		VALUES (100, 'MSN Messenger', 1, 1)
END
GO

