/*
 * $Id: spm-migprep715.sql 101389 2011-11-25 01:51:25Z rlowery $
 *
 * Prepare to migrate a SPM 7.0 database into SPM 7.1 format.
 *
 * Use this first, then schema.sql, then migpost.sql, and finally
 * install SPM 7.1 which will create the stored procedures.
 *
 * The aim here is to make minimal changes that will allow schema.sql
 * to succeed in creating any new objects, before migpost.sql finishes
 * reshaping some tables and dropping any unused objects.
 *
 * Copyright 2011 Flexera Software LLC
 */

USE ManageSoft
GO

/*
 * Check that we are upgrading from a 7.0 database...
 */
DECLARE @spm_schema_version char(10)
SET @spm_schema_version = (SELECT Value FROM DatabaseConfiguration
		WHERE Property = 'SPMSchemaVersion')

IF @spm_schema_version IS NULL
	SET @spm_schema_version = (SELECT Value FROM DatabaseConfiguration
			WHERE Property = 'SchemaVersion')
		
IF (@spm_schema_version = '7.1')
BEGIN
	PRINT 'Preparing to migrate database from ManageSoft SPM 7.1 schema...'
END
ELSE IF (@spm_schema_version = '7.1.5')
BEGIN
        RAISERROR ('Your ManageSoft database has already been migrated to the 7.1.5 schema.', 16, 1)
        RAISERROR ('For more information on migrating your database, refer to the ManageSoft Upgrade Guide.', 16, 1)
END
ELSE
BEGIN
	RAISERROR ('This script can only migrate from the ManageSoft SPM database schema version 7.1.', 16, 1)
	RAISERROR ('Please migrate your database schema to version 7.1 before executing this script again.', 16, 1)
        RAISERROR ('For more information on migrating your database, refer to the ManageSoft Upgrade Guide.', 16, 1)
END
GO


--===========================================================================
--		Alter the SecurityBulletin table
--===========================================================================

PRINT 'Add Errata column to SecurityBulletin'
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityBulletin'
)
BEGIN
	-- Add Errata column
	ALTER TABLE SecurityBulletin ADD Errata nvarchar(64) NULL
END

GO

PRINT 'Populate Errata column to SecurityBulletin'
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityBulletin'
)
BEGIN
	-- Update errata column
	UPDATE SecurityBulletin
	SET Errata = 'microsoftwindows'
	WHERE BulletinID LIKE 'MS%'
	
	-- Update errata column
	UPDATE SecurityBulletin
	SET Errata = 'microsoftoffice'
	WHERE BulletinID LIKE 'OF%'
END

GO

--===========================================================================
--		Alter the SecurityPatch table
--===========================================================================

PRINT 'Remove language foreign key on SecurityPatch table'
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatch'
)
BEGIN
	-- Remove foreign key constraint
	IF EXISTS (
		SELECT *
		FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = 'FK_SecurityPatch_Language'
	)
	BEGIN
		ALTER TABLE SecurityPatch DROP CONSTRAINT FK_SecurityPatch_Language
	END
END

GO

--===========================================================================
--		Delete the SecurityPatch_Language table
--===========================================================================

PRINT 'Removing SecurityPatch_Language table'
IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatch_Language'
)
BEGIN
	-- Drop table
	DROP TABLE SecurityPatch_Language
END

GO

