/*
 * $Id: spm-migprep76.sql 101389 2011-11-25 01:51:25Z rlowery $
 *
 * Prepare to migrate a SPM 7.2 database into SPM 7.5 format.
 *
 * Use this first, then schema.sql, then migpost.sql, and finally
 * install SPM 7.5 which will create the stored procedures.
 *
 * The aim here is to make minimal changes that will allow schema.sql
 * to succeed in creating any new objects, before migpost.sql finishes
 * reshaping some tables and dropping any unused objects.
 *
 * Copyright 2011 Flexera Software LLC
 */
 
USE ManageSoft
GO

--===========================================================================
--		Remove obsolete tables
--===========================================================================

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_FileChg'
)
BEGIN
	PRINT 'Removing obsolete table SecPatch_FileChg'
	DROP TABLE SecPatch_FileChg
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_FileChange'
)
BEGIN
	PRINT 'Removing obsolete table SecPatch_FileChange'
	DROP TABLE SecPatch_FileChange
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_RegChg'
)
BEGIN
	PRINT 'Removing obsolete table SecPatch_RegChg'
	DROP TABLE SecPatch_RegChg
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_RegChange'
)
BEGIN
	PRINT 'Removing obsolete table SecPatch_RegChange'
	DROP TABLE SecPatch_RegChange
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_RegKey'
)
BEGIN
	PRINT 'Removing obsolete table SecPatch_RegKey'
	DROP TABLE SecPatch_RegKey
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_File'
)
BEGIN
	PRINT 'Removing obsolete table SecPatch_File'
	DROP TABLE SecPatch_File
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_AvailableSP'
)
BEGIN
	PRINT 'Removing obsolete table SecPatch_AvailableSP'
	DROP TABLE SecPatch_AvailableSP
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_Command'
)
BEGIN
	PRINT 'Removing obsolete table SecPatch_Command'
	DROP TABLE SecPatch_Command
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecPatch_SUSMapping'
)
BEGIN
	PRINT 'Removing obsolete table SecPatch_SUSMapping'
	DROP TABLE SecPatch_SUSMapping
END
GO

--===========================================================================
--		Update SecurityPatch table
--===========================================================================

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatch'
) AND NOT EXISTS(
	SELECT *
	FROM INFORMATION_SCHEMA.COLUMNS
	WHERE TABLE_NAME = 'SecurityPatch'
	AND COLUMN_NAME = 'DefaultInstallCmdLineOptions'
)
BEGIN
	ALTER TABLE SecurityPatch ADD DefaultInstallCmdLineOptions nvarchar(256) NULL
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.TABLES
	WHERE TABLE_NAME = 'SecurityPatch'
) AND NOT EXISTS(
	SELECT *
	FROM INFORMATION_SCHEMA.COLUMNS
	WHERE TABLE_NAME = 'SecurityPatch'
	AND COLUMN_NAME = 'DefaultUnInstallCmdLineOptions'
)
BEGIN
	ALTER TABLE SecurityPatch ADD DefaultUnInstallCmdLineOptions nvarchar(256) NULL
END
GO

--===========================================================================
--		Update constraints
--===========================================================================

IF NOT EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'UQ_SecurityPatchUIProductGroupByProduct'
)
BEGIN
	-- If duplicate entries have been added (you know who you are :-), we
	-- delete the more recent one. If uniqueness is still violated, it's
	-- because the product is in more than one group and you must fix it.
	DELETE	s1
	FROM	SecurityPatchUIProductGroup AS s1,
		SecurityPatchUIProductGroup AS s2
	WHERE	s1.Product = s2.Product
	  AND	s1.GroupName = s1.GroupName
	  AND	s1.SecurityPatchUIProductGroupID > s2.SecurityPatchUIProductGroupID

	ALTER TABLE SecurityPatchUIProductGroup	ADD CONSTRAINT UQ_SecurityPatchUIProductGroupByProduct UNIQUE NONCLUSTERED(Product)
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_AffectedServicePack_AffectedProduct'
)
BEGIN
	ALTER TABLE SecPatch_AffectedServicePack DROP CONSTRAINT FK_AffectedServicePack_AffectedProduct
	ALTER TABLE SecPatch_AffectedServicePack
		ADD CONSTRAINT FK_AffectedServicePack_AffectedProduct
		FOREIGN KEY(AffectedProductID)
		REFERENCES SecPatch_AffectedProduct(AffectedProductID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_ProductProductFamily_ProductFamily'
)
BEGIN
	ALTER TABLE SecPatch_ProductProductFamily DROP CONSTRAINT FK_ProductProductFamily_ProductFamily
	ALTER TABLE SecPatch_ProductProductFamily
		ADD CONSTRAINT FK_ProductProductFamily_ProductFamily
		FOREIGN KEY(ProductFamilyID)
		REFERENCES SecPatch_ProductFamily(ProductFamilyID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_BulletinComment_Comment'
)
BEGIN
	ALTER TABLE SecPatch_BulletinComment DROP CONSTRAINT FK_BulletinComment_Comment
	ALTER TABLE SecPatch_BulletinComment
		ADD CONSTRAINT FK_BulletinComment_Comment
		FOREIGN KEY(CommentID)
		REFERENCES SecPatch_Comment(CommentID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_Patch_Location'
)
BEGIN
	ALTER TABLE SecPatch_Patch DROP CONSTRAINT FK_Patch_Location
	ALTER TABLE SecPatch_Patch
		ADD CONSTRAINT FK_Patch_Location
		FOREIGN KEY(PatchLocationID)
		REFERENCES SecPatch_Location(LocationID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_Patch_SupercededBy'
)
BEGIN
	ALTER TABLE SecPatch_Patch DROP CONSTRAINT FK_Patch_SupercededBy
	ALTER TABLE SecPatch_Patch
		ADD CONSTRAINT FK_Patch_SupercededBy
		FOREIGN KEY(SBID)
		REFERENCES SecPatch_SupercededBy(SBID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'SecPatch_PatchComment'
)
BEGIN
	ALTER TABLE SecPatch_PatchComment DROP CONSTRAINT FK_PatchComment_Comment
	ALTER TABLE SecPatch_PatchComment
		ADD CONSTRAINT FK_PatchComment_Comment
		FOREIGN KEY(CommentID)
		REFERENCES SecPatch_Comment(CommentID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_PatchComment_Patch'
)
BEGIN
	ALTER TABLE SecPatch_PatchComment DROP CONSTRAINT FK_PatchComment_Patch
	ALTER TABLE SecPatch_PatchComment
		ADD CONSTRAINT FK_PatchComment_Patch
		FOREIGN KEY(PatchID)
		REFERENCES SecPatch_Patch(PatchID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SupercededPatch_SupercededBy'
)
BEGIN
	ALTER TABLE SecPatch_SupercededPatch DROP CONSTRAINT FK_SupercededPatch_SupercededBy
	ALTER TABLE SecPatch_SupercededPatch
		ADD CONSTRAINT FK_SupercededPatch_SupercededBy
		FOREIGN KEY(SupercededByID)
		REFERENCES SecPatch_SupercededBy(SBID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityBulletinToUserState_SecurityBulletin'
)
BEGIN
	ALTER TABLE SecurityBulletinToUserState DROP CONSTRAINT FK_SecurityBulletinToUserState_SecurityBulletin
	ALTER TABLE SecurityBulletinToUserState
		ADD CONSTRAINT FK_SecurityBulletinToUserState_SecurityBulletin
		FOREIGN KEY(SecurityBulletinID)
		REFERENCES SecurityBulletin(SecurityBulletinID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatch_SecurityBulletin'
)
BEGIN
	ALTER TABLE SecurityPatch DROP CONSTRAINT FK_SecurityPatch_SecurityBulletin
	ALTER TABLE SecurityPatch
		ADD CONSTRAINT FK_SecurityPatch_SecurityBulletin
		FOREIGN KEY(BulletinID)
		REFERENCES SecurityBulletin(BulletinID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatch_Locale'
)
BEGIN
	ALTER TABLE SecurityPatch DROP CONSTRAINT FK_SecurityPatch_Locale
	ALTER TABLE SecurityPatch
		ADD CONSTRAINT FK_SecurityPatch_Locale
		FOREIGN KEY(LanguageID)
		REFERENCES Locale(LocaleCode) ON DELETE NO ACTION
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatchRequires_SecurityPatch'
)
BEGIN
	ALTER TABLE SecurityPatchRequires DROP CONSTRAINT FK_SecurityPatchRequires_SecurityPatch
	ALTER TABLE SecurityPatchRequires
		ADD CONSTRAINT FK_SecurityPatchRequires_SecurityPatch
		FOREIGN KEY(PatchID)
		REFERENCES SecurityPatch(PatchID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatchToPackageVersion_SecurityPatch'
)
BEGIN
	ALTER TABLE SecurityPatchToPackageVersion DROP CONSTRAINT FK_SecurityPatchToPackageVersion_SecurityPatch
	ALTER TABLE SecurityPatchToPackageVersion
		ADD CONSTRAINT FK_SecurityPatchToPackageVersion_SecurityPatch
		FOREIGN KEY(PatchID)
		REFERENCES SecurityPatch(PatchID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityStateChange_SecurityBulletin'
)
BEGIN
	ALTER TABLE SecurityStateChange DROP CONSTRAINT FK_SecurityStateChange_SecurityBulletin
	ALTER TABLE SecurityStateChange
		ADD CONSTRAINT FK_SecurityStateChange_SecurityBulletin
		FOREIGN KEY(BulletinID)
		REFERENCES SecurityBulletin(BulletinID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityUserStateChange_SecurityState'
)
BEGIN
	ALTER TABLE SecurityUserStateChange DROP CONSTRAINT FK_SecurityUserStateChange_SecurityState
	ALTER TABLE SecurityUserStateChange
		ADD CONSTRAINT FK_SecurityUserStateChange_SecurityState
		FOREIGN KEY(UserStateID)
		REFERENCES SecurityUserState(UserStateID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityUserStateChange_SecurityBulletin'
)
BEGIN
	ALTER TABLE SecurityUserStateChange DROP CONSTRAINT FK_SecurityUserStateChange_SecurityBulletin
	ALTER TABLE SecurityUserStateChange
		ADD CONSTRAINT FK_SecurityUserStateChange_SecurityBulletin
		FOREIGN KEY(SecurityBulletinID)
		REFERENCES SecurityBulletin(SecurityBulletinID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatchAnalysis_SecutityPatch'
)
BEGIN
	ALTER TABLE SecurityPatchAnalysis DROP CONSTRAINT FK_SecurityPatchAnalysis_SecutityPatch
	ALTER TABLE SecurityPatchAnalysis
		ADD CONSTRAINT FK_SecurityPatchAnalysis_SecutityPatch
		FOREIGN KEY(SecurityPatchID)
		REFERENCES SecurityPatch(PatchID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatchUninstallValues_SecurityPatch'
)
BEGIN
	ALTER TABLE SecurityPatchUninstallValues DROP CONSTRAINT FK_SecurityPatchUninstallValues_SecurityPatch
	ALTER TABLE SecurityPatchUninstallValues
		ADD CONSTRAINT FK_SecurityPatchUninstallValues_SecurityPatch
		FOREIGN KEY(SecurityPatchID)
		REFERENCES SecurityPatch(PatchID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatchResource_SecurityPatchID'
)
BEGIN
	ALTER TABLE SecurityPatchResource DROP CONSTRAINT FK_SecurityPatchResource_SecurityPatchID
	ALTER TABLE SecurityPatchResource
		ADD CONSTRAINT FK_SecurityPatchResource_SecurityPatchID
		FOREIGN KEY(SecurityPatchID)
		REFERENCES SecurityPatch(PatchID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatchResource_Locale'
)
BEGIN
	ALTER TABLE SecurityPatchResource DROP CONSTRAINT FK_SecurityPatchResource_Locale
	ALTER TABLE SecurityPatchResource
		ADD CONSTRAINT FK_SecurityPatchResource_Locale
		FOREIGN KEY(LanguageID)
		REFERENCES Locale(LocaleCode) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatchResourceProduct_SecurityPatchResource'
)
BEGIN
	ALTER TABLE SecurityPatchResourceProduct DROP CONSTRAINT FK_SecurityPatchResourceProduct_SecurityPatchResource
	ALTER TABLE SecurityPatchResourceProduct
		ADD CONSTRAINT FK_SecurityPatchResourceProduct_SecurityPatchResource
		FOREIGN KEY(SecurityPatchResourceID)
		REFERENCES SecurityPatchResource(SecurityPatchResourceID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatchResourceProduct_SecurityPatchProduct'
)
BEGIN
	ALTER TABLE SecurityPatchResourceProduct DROP CONSTRAINT FK_SecurityPatchResourceProduct_SecurityPatchProduct
	ALTER TABLE SecurityPatchResourceProduct
		ADD CONSTRAINT FK_SecurityPatchResourceProduct_SecurityPatchProduct
		FOREIGN KEY(SecurityPatchProductID)
		REFERENCES SecurityPatchProduct(SecurityPatchProductID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatchLanguage_Locale'
)
BEGIN
	ALTER TABLE SecurityPatchLanguage DROP CONSTRAINT FK_SecurityPatchLanguage_Locale
	ALTER TABLE SecurityPatchLanguage
		ADD CONSTRAINT FK_SecurityPatchLanguage_Locale
		FOREIGN KEY(LanguageName)
		REFERENCES Locale(LocaleCode) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatchOperatingSystem_SecurityPatchUIProductGroup'
)
BEGIN
	ALTER TABLE SecurityPatchOperatingSystem DROP CONSTRAINT FK_SecurityPatchOperatingSystem_SecurityPatchUIProductGroup
	ALTER TABLE SecurityPatchOperatingSystem
		ADD CONSTRAINT FK_SecurityPatchOperatingSystem_SecurityPatchUIProductGroup
		FOREIGN KEY(OperatingSystemID)
		REFERENCES SecurityPatchUIProductGroup(SecurityPatchUIProductGroupID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatchApplication_SecurityPatchUIProductGroup'
)
BEGIN
	ALTER TABLE SecurityPatchApplication DROP CONSTRAINT FK_SecurityPatchApplication_SecurityPatchUIProductGroup
	ALTER TABLE SecurityPatchApplication
		ADD CONSTRAINT FK_SecurityPatchApplication_SecurityPatchUIProductGroup
		FOREIGN KEY(ApplicationID)
		REFERENCES SecurityPatchUIProductGroup(SecurityPatchUIProductGroupID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_AffectedProduct_Patch'
)
BEGIN
	ALTER TABLE SecPatch_AffectedProduct DROP CONSTRAINT FK_AffectedProduct_Patch
	ALTER TABLE SecPatch_AffectedProduct
		ADD CONSTRAINT FK_AffectedProduct_Patch
		FOREIGN KEY(PatchID)
		REFERENCES SecPatch_Patch(PatchID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_AffectedProduct_Product'
)
BEGIN
	ALTER TABLE SecPatch_AffectedProduct DROP CONSTRAINT FK_AffectedProduct_Product
	ALTER TABLE SecPatch_AffectedProduct
		ADD CONSTRAINT FK_AffectedProduct_Product
		FOREIGN KEY(ProductID)
		REFERENCES SecPatch_Product(ProductID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_AffectedServicePack_ServicePack'
)
BEGIN
	ALTER TABLE SecPatch_AffectedServicePack DROP CONSTRAINT FK_AffectedServicePack_ServicePack
	ALTER TABLE SecPatch_AffectedServicePack
		ADD CONSTRAINT FK_AffectedServicePack_ServicePack
		FOREIGN KEY(ServicePackID)
		REFERENCES SecPatch_ServicePack(ServicePackID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_BulletinComment_Bulletin'
)
BEGIN
	ALTER TABLE SecPatch_BulletinComment DROP CONSTRAINT FK_BulletinComment_Bulletin
	ALTER TABLE SecPatch_BulletinComment
		ADD CONSTRAINT FK_BulletinComment_Bulletin
		FOREIGN KEY(BulletinID)
		REFERENCES SecPatch_Bulletin(BulletinID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_qNumber_Bulletin'
)
BEGIN
	ALTER TABLE SecPatch_QNumber DROP CONSTRAINT FK_qNumber_Bulletin
	ALTER TABLE SecPatch_QNumber
		ADD CONSTRAINT FK_qNumber_Bulletin
		FOREIGN KEY(BulletinID)
		REFERENCES SecPatch_Bulletin(BulletinID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_Patch_Bulletin'
)
BEGIN
	ALTER TABLE SecPatch_Patch DROP CONSTRAINT FK_Patch_Bulletin
	ALTER TABLE SecPatch_Patch
		ADD CONSTRAINT FK_Patch_Bulletin
		FOREIGN KEY(BulletinID)
		REFERENCES SecPatch_Bulletin(BulletinID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_Patch_SecurityPatch'
)
BEGIN
	ALTER TABLE SecPatch_Patch DROP CONSTRAINT FK_Patch_SecurityPatch
	ALTER TABLE SecPatch_Patch
		ADD CONSTRAINT FK_Patch_SecurityPatch
		FOREIGN KEY(SecurityPatchID)
		REFERENCES SecurityPatch(PatchID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SupercededPatch_Bulletin'
)
BEGIN
	ALTER TABLE SecPatch_SupercededPatch DROP CONSTRAINT FK_SupercededPatch_Bulletin
	ALTER TABLE SecPatch_SupercededPatch
		ADD CONSTRAINT FK_SupercededPatch_Bulletin
		FOREIGN KEY(BulletinID)
		REFERENCES SecPatch_Bulletin(BulletinID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityBulletinToUserState_SecurityUserState'
)
BEGIN
	ALTER TABLE SecurityBulletinToUserState DROP CONSTRAINT FK_SecurityBulletinToUserState_SecurityUserState
	ALTER TABLE SecurityBulletinToUserState
		ADD CONSTRAINT FK_SecurityBulletinToUserState_SecurityUserState
		FOREIGN KEY(UserStateID)
		REFERENCES SecurityUserState(UserStateID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityPatchAnalysis_SecutityPatchStatus'
)
BEGIN
	ALTER TABLE SecurityPatchAnalysis DROP CONSTRAINT FK_SecurityPatchAnalysis_SecutityPatchStatus
	ALTER TABLE SecurityPatchAnalysis
		ADD CONSTRAINT FK_SecurityPatchAnalysis_SecutityPatchStatus
		FOREIGN KEY(Status)
		REFERENCES SecurityPatchStatus(SecurityPatchStatusID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityBulletinChange_SecurityBulletinChangeType'
)
BEGIN
	ALTER TABLE SecurityBulletinChange DROP CONSTRAINT FK_SecurityBulletinChange_SecurityBulletinChangeType
	ALTER TABLE SecurityBulletinChange
		ADD CONSTRAINT FK_SecurityBulletinChange_SecurityBulletinChangeType
		FOREIGN KEY(ChangeTypeID)
		REFERENCES SecurityBulletinChangeType(SecurityBulletinChangeTypeID) ON DELETE CASCADE
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_SecurityBulletinChange_SecurityBulletinChangeType'
)
BEGIN
	ALTER TABLE SecurityBulletinChange DROP CONSTRAINT FK_SecurityBulletinChange_SecurityBulletinChangeType
	ALTER TABLE SecurityBulletinChange
		ADD CONSTRAINT FK_SecurityBulletinChange_SecurityBulletinChangeType
		FOREIGN KEY(ChangeTypeID)
		REFERENCES SecurityBulletinChangeType(SecurityBulletinChangeTypeID) ON DELETE CASCADE
END
GO

--===========================================================================
--		Remove constraints
--===========================================================================

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_Bulletin_Severity'
)
BEGIN
	ALTER TABLE SecPatch_Bulletin DROP CONSTRAINT FK_Bulletin_Severity
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_Bulletin_Severity1'
)
BEGIN
	ALTER TABLE SecPatch_Bulletin DROP CONSTRAINT FK_Bulletin_Severity1
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_Bulletin_Severity2'
)
BEGIN
	ALTER TABLE SecPatch_Bulletin DROP CONSTRAINT FK_Bulletin_Severity2
END
GO

IF EXISTS (
	SELECT *
	FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
	WHERE CONSTRAINT_NAME = 'FK_Bulletin_Severity3'
)
BEGIN
	ALTER TABLE SecPatch_Bulletin DROP CONSTRAINT FK_Bulletin_Severity3
END
GO

