/*
 * $Id: spm-migprep79.sql 101389 2011-11-25 01:51:25Z rlowery $
 *
 * Prepare to migrate a SPM 7.8 database into SM 7.9 format.
 *
 * Use this first, then schema.sql, then migpost.sql, AND finally
 * install SM 7.9 which will create the stored procedures.
 *
 * The aim here is to make minimal changes that will allow schema.sql
 * to succeed in creating any new objects, before migpost.sql finishes
 * reshaping some tables AND dropping any unused objects.
 *
 * Copyright 2011 Flexera Software LLC
 */
 
USE ManageSoft

IF NOT EXISTS(SELECT * FROM DatabaseConfiguration WHERE Property = 'SMMigrationStep')
	INSERT DatabaseConfiguration (Property, Value) VALUES ('SMMigrationStep', 0)
ELSE
BEGIN
	DECLARE @step int
	SELECT @step = Value FROM DatabaseConfiguration WHERE Property = 'SMMigrationStep'
	PRINT 'Restarting migration from step '+STR(@step + 1, 2)
END
GO

--
-- SecPatch_ProductProductFamily table
--

-- Alter constraints
IF EXISTS(SELECT * FROM DatabaseConfiguration WHERE Property = 'SMMigrationStep' AND VALUE = 0)
BEGIN
	-- Drop the constraint
	If (Object_ID('UQ_ProductProductFamily') IS NOT NULL)
	        ALTER TABLE SecPatch_ProductProductFamily DROP CONSTRAINT UQ_ProductProductFamily

	-- Re-create the  constraint
	ALTER TABLE SecPatch_ProductProductFamily ADD CONSTRAINT
		PK_ProductProductFamily PRIMARY KEY NONCLUSTERED(ProductID, ProductFamilyID)

	UPDATE DatabaseConfiguration SET Value = 1 WHERE Property = 'SMMigrationStep'
END
GO

IF EXISTS(SELECT * FROM DatabaseConfiguration WHERE Property = 'SMMigrationStep' AND VALUE = 1)
BEGIN
	DELETE FROM SecurityPatchAnalysis
	WHERE NOT EXISTS
	(
		SELECT * FROM Computer
		WHERE Computer.ComputerID = SecurityPatchAnalysis.ComputerID
	)
	UPDATE DatabaseConfiguration SET Value = 2 WHERE Property = 'SMMigrationStep'
END
GO

IF EXISTS(SELECT * FROM DatabaseConfiguration WHERE Property = 'SMMigrationStep' AND VALUE = 2)
BEGIN
	DELETE FROM SecurityAnalysisReport
	WHERE NOT EXISTS
	(
		SELECT * FROM Computer
		WHERE Computer.ComputerID = SecurityAnalysisReport.ComputerID
	)
	UPDATE DatabaseConfiguration SET Value = 3 WHERE Property = 'SMMigrationStep'
END
GO

IF EXISTS(SELECT * FROM DatabaseConfiguration WHERE Property = 'SMMigrationStep' AND VALUE = 3)
BEGIN
	UPDATE DatabaseConfiguration SET Value = 1000 WHERE Property = 'SMMigrationStep'
END
GO

