/*
 * $Id: spm-migprep.sql 101389 2011-11-25 01:51:25Z rlowery $
 *
 * Prepare to migrate a SPM 8.4 database into SM 8.5 format.
 *
 * Use this first, then schema.sql, then migpost.sql, AND finally
 * install SM 8.5 which will create the stored procedures.
 *
 * The aim here is to make minimal changes that will allow schema.sql
 * to succeed in creating any new objects, before migpost.sql finishes
 * reshaping some tables AND dropping any unused objects.
 *
 * Copyright 2011 Flexera Software LLC
 */
 
USE ManageSoft

IF NOT EXISTS(SELECT * FROM DatabaseConfiguration WHERE Property = 'SMMigrationStep')
	INSERT DatabaseConfiguration (Property, Value) VALUES ('SMMigrationStep', 0)
ELSE
BEGIN
	DECLARE @step int
	SELECT @step = Value FROM DatabaseConfiguration WHERE Property = 'SMMigrationStep'
	PRINT 'Restarting migration from step '+STR(@step + 1, 2)
END
GO

IF EXISTS(SELECT * FROM DatabaseConfiguration WHERE Property = 'SMMigrationStep' AND VALUE = 0)
BEGIN
	-- Drop redundant index
	IF EXISTS (
		SELECT * FROM sysindexes
		WHERE name = N'AffectedServicePackByAffectedProductID'
	)
		DROP INDEX AffectedServicePackByAffectedProductID
			ON SecPatch_AffectedServicePack

	-- Drop foreign keys that refer to an index to be dropped and re-created
	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_AffectedProduct_Product'
	)
		ALTER TABLE SecPatch_AffectedProduct
			DROP CONSTRAINT FK_AffectedProduct_Product

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_ProductProductFamily_Product'
	)
		ALTER TABLE SecPatch_ProductProductFamily
			DROP CONSTRAINT FK_ProductProductFamily_Product

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_SecurityBulletinRequires_SecurityBulletin'
	)
		ALTER TABLE SecurityBulletinRequires
			DROP CONSTRAINT FK_SecurityBulletinRequires_SecurityBulletin

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_SecurityBulletinRequires2_SecurityBulletin'
	)
		ALTER TABLE SecurityBulletinRequires
			DROP CONSTRAINT FK_SecurityBulletinRequires2_SecurityBulletin

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_SecurityBulletinToUserState_SecurityBulletin'
	)
		ALTER TABLE SecurityBulletinToUserState
			DROP CONSTRAINT FK_SecurityBulletinToUserState_SecurityBulletin

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_SecurityUserStateChange_SecurityBulletin'
	)
		ALTER TABLE SecurityUserStateChange
			DROP CONSTRAINT FK_SecurityUserStateChange_SecurityBulletin

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_SecurityPatchAlias_SecurityPatch'
	)
		ALTER TABLE SecurityPatchAlias
			DROP CONSTRAINT FK_SecurityPatchAlias_SecurityPatch

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_Patch_SecurityPatch'
	)
		ALTER TABLE SecPatch_Patch
			DROP CONSTRAINT FK_Patch_SecurityPatch

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_SecurityPatchResource_SecurityPatchID'
	)
		ALTER TABLE SecurityPatchResource
			DROP CONSTRAINT FK_SecurityPatchResource_SecurityPatchID

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_SecurityPatchUninstallValues_SecurityPatch'
	)
		ALTER TABLE SecurityPatchUninstallValues
			DROP CONSTRAINT FK_SecurityPatchUninstallValues_SecurityPatch

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_SecurityPatchAnalysis_SecutityPatch'
	)
		ALTER TABLE SecurityPatchAnalysis
			DROP CONSTRAINT FK_SecurityPatchAnalysis_SecutityPatch

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_SecurityPatchAnalysis_SecutityPatchStatus'
	)
		ALTER TABLE SecurityPatchAnalysis
			DROP CONSTRAINT FK_SecurityPatchAnalysis_SecutityPatchStatus

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_SecurityPatchToPackageVersion_SecurityPatch'
	)
		ALTER TABLE SecurityPatchToPackageVersion
			DROP CONSTRAINT FK_SecurityPatchToPackageVersion_SecurityPatch

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_SecurityPatchRequires_SecurityPatch'
	)
		ALTER TABLE SecurityPatchRequires
			DROP CONSTRAINT FK_SecurityPatchRequires_SecurityPatch

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_SecurityPatchRequires2_SecurityPatch'
	)
		ALTER TABLE SecurityPatchRequires
			DROP CONSTRAINT FK_SecurityPatchRequires2_SecurityPatch

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_SecurityBulletinChange_SecurityBulletinChangeType'
	)
		ALTER TABLE SecurityBulletinChange
			DROP CONSTRAINT FK_SecurityBulletinChange_SecurityBulletinChangeType

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_Threat_ThreatType'
	)
		ALTER TABLE Threat
			DROP CONSTRAINT FK_Threat_ThreatType

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_Threat_ThreatRisk'
	)
		ALTER TABLE Threat
			DROP CONSTRAINT FK_Threat_ThreatRisk

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_ThreatCategory_ThreatType'
	)
		ALTER TABLE ThreatCategory
			DROP CONSTRAINT FK_ThreatCategory_ThreatType

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_ThreatMessageLog_Threat'
	)
		ALTER TABLE ThreatLog
			DROP CONSTRAINT FK_ThreatMessageLog_Threat

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_ThreatOccurrence_Threat'
	)
		ALTER TABLE ThreatOccurrence
			DROP CONSTRAINT FK_ThreatOccurrence_Threat

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_ThreatOccurrence_ThreatType'
	)
		ALTER TABLE ThreatOccurrence
			DROP CONSTRAINT FK_ThreatOccurrence_ThreatType

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_ThreatOccurrence_ThreatAction'
	)
		ALTER TABLE ThreatOccurrence
			DROP CONSTRAINT FK_ThreatOccurrence_ThreatAction

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_ThreatOccurrence_ThreatRisk'
	)
		ALTER TABLE ThreatOccurrence
			DROP CONSTRAINT FK_ThreatOccurrence_ThreatRisk

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_ThreatOccurrence_ThreatScanner'
	)
		ALTER TABLE ThreatOccurrence
			DROP CONSTRAINT FK_ThreatOccurrence_ThreatScanner

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_ThreatScan_ThreatType'
	)
		ALTER TABLE ThreatScan
			DROP CONSTRAINT FK_ThreatScan_ThreatType

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_ThreatScan_ThreatScanner'
	)
		ALTER TABLE ThreatScan
			DROP CONSTRAINT FK_ThreatScan_ThreatScanner

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_ThreatScannerToType_ThreatType'
	)
		ALTER TABLE ThreatScannerToType
			DROP CONSTRAINT FK_ThreatScannerToType_ThreatType

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_ThreatScannerToType_ThreatScanner'
	)
		ALTER TABLE ThreatScannerToType
			DROP CONSTRAINT FK_ThreatScannerToType_ThreatScanner

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_ThreatToCategory_ThreatCategory'
	)
		ALTER TABLE ThreatToCategory
			DROP CONSTRAINT FK_ThreatToCategory_ThreatCategory

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_ThreatToCategory_Threat'
	)
		ALTER TABLE ThreatToCategory
			DROP CONSTRAINT FK_ThreatToCategory_Threat

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_ThreatToScanner_ThreatScanner'
	)
		ALTER TABLE ThreatToScanner
			DROP CONSTRAINT FK_ThreatToScanner_ThreatScanner

	IF EXISTS (
		SELECT * FROM INFORMATION_SCHEMA.CONSTRAINT_COLUMN_USAGE
		WHERE CONSTRAINT_NAME = N'FK_ThreatToScanner_Threat'
	)
		ALTER TABLE ThreatToScanner
			DROP CONSTRAINT FK_ThreatToScanner_Threat

	UPDATE DatabaseConfiguration SET Value = 1 WHERE Property = 'SMMigrationStep'
END
GO

IF EXISTS(SELECT * FROM DatabaseConfiguration WHERE Property = 'SMMigrationStep' AND VALUE = 1)
BEGIN
	UPDATE DatabaseConfiguration SET Value = 1000 WHERE Property = 'SMMigrationStep'
END
GO

